@@ -14,17 +14,17 @@
 from horizon.test.settings import *  # noqa
 from openstack_dashboard.test.settings import *  # noqa
 
+import openstack_dashboard.enabled
+from openstack_dashboard.utils import settings
+
+import neutron_fwaas_dashboard.enabled
+
 # pop these keys to avoid log warnings about deprecation
 # update_dashboards will populate them anyway
 HORIZON_CONFIG.pop('dashboards', None)
 HORIZON_CONFIG.pop('default_dashboard', None)
 
 # Update the dashboards with neutron_fwaas_dashboard
-import openstack_dashboard.enabled
-from openstack_dashboard.utils import settings
-
-import neutron_fwaas_dashboard.enabled
-
 settings.update_dashboards(
     [
         openstack_dashboard.enabled,
@@ -49,3 +49,8 @@ TEST_GLOBAL_MOCKS_ON_PANELS['firewalls'] = {
                'Firewall.can_access'),
     'return_value': True,
 }
+TEST_GLOBAL_MOCKS_ON_PANELS['firewalls_v2'] = {
+    'method': ('neutron_fwaas_dashboard.dashboards.project.firewalls_v2.panel.'
+               'Firewall_V2.can_access'),
+    'return_value': True,
+}
